'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _device = require('./device');

var _device2 = _interopRequireDefault(_device);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const CRYPTID_ENDPOINT = 'https://cryptid.adorable.io/api/events';

function post(event, options) {
  let url = options.url || CRYPTID_ENDPOINT;
  let requestOptions = options.request || {};
  let beforeFetch = options.beforeFetch,
      afterFetch = options.afterFetch;


  let mergedOptions = _extends({
    method: 'POST',
    headers: {
      'Content-Type': 'application/json'
    },
    body: JSON.stringify(event)
  }, requestOptions);

  if (beforeFetch) beforeFetch(url, mergedOptions);

  return fetch(url, mergedOptions).catch(err => console.error(err)).then(response => {
    if (afterFetch) afterFetch(response);
  });
}

function generatePayload(trackerId, event) {
  return {
    event: _extends({
      trackerId: trackerId
    }, (0, _device2.default)(), event)
  };
}

class Tracker {
  constructor(trackerId, options = {}) {
    this.trackerId = trackerId;
    this.options = options;
    this.post = post;
  }

  send(event) {
    return this.post(generatePayload(this.trackerId, event), this.options);
  }
}
exports.default = Tracker;